@@ -157,15 +157,8 @@ static XrmOptionDescRec options[] = {
 # endif
 #endif
 
-#if defined(_AIX)
-#  define USE_PTS
-#endif
-
 #if !defined (USE_FILE) || defined (linux)
 # include <sys/ioctl.h>
-# ifdef hpux
-#  include <termios.h>
-# endif
 # if defined (SVR4) || defined (USE_PTS)
 #  include <termios.h>
 #  ifndef HAS_OPENPTY
@@ -178,43 +171,24 @@ static XrmOptionDescRec options[] = {
 # if defined(TIOCCONS) || defined(SRIOCSREDIR)
 #  define USE_PTY
 static int  tty_fd, pty_fd;
-static char ttydev[64], ptydev[64];
 # endif
 #endif
 
-#if (defined(SVR4) && !defined(sun)) || (defined(SYSV) && defined(i386))
-#define USE_OSM
-#include <signal.h>
-#endif
-
 #ifdef USE_PTY
-static int get_pty(int *pty, int *tty, char *ttydev, char *ptydev);
-#endif
-
-#ifdef USE_OSM
-static FILE *osm_pipe(void);
-static int child_pid;
+static int get_pty(int *pty, int *tty);
 #endif
 
 /* Copied from xterm/ptyx.h */
 #ifndef PTYCHAR1
-#ifdef __hpux
-#define PTYCHAR1        "zyxwvutsrqp"
-#else   /* !__hpux */
 #define PTYCHAR1        "pqrstuvwxyzPQRSTUVWXYZ"
-#endif  /* !__hpux */
 #endif  /* !PTYCHAR1 */
 
 #ifndef PTYCHAR2
-#ifdef __hpux
-#define PTYCHAR2        "fedcba9876543210"
-#else   /* !__hpux */
 #ifdef __FreeBSD__
 #define PTYCHAR2        "0123456789abcdefghijklmnopqrstuv"
 #else /* !__FreeBSD__ */
 #define PTYCHAR2        "0123456789abcdef"
 #endif /* !__FreeBSD__ */
-#endif  /* !__hpux */
 #endif  /* !PTYCHAR2 */
 
 static void
@@ -243,7 +217,7 @@ OpenConsole(void)
 #endif
 
 #ifdef USE_PTY
-		if (!input && get_pty (&pty_fd, &tty_fd, ttydev, ptydev) == 0)
+		if (!input && get_pty (&pty_fd, &tty_fd) == 0)
 		{
 # ifdef TIOCCONS
 		    int on = 1;
@@ -261,11 +235,6 @@ OpenConsole(void)
 		}
 #endif /* USE_PTY */
 	    }
-#ifdef USE_OSM
-	    /* Don't have to be owner of /dev/console when using /dev/osm. */
-	    if (!input)
-		input = osm_pipe();
-#endif
 	    if (input && app_resources.verbose)
 	    {
 		char	*hostname;
@@ -328,39 +297,13 @@ CloseConsole (void)
 #endif
 }
 
-#ifdef USE_OSM
-static void
-KillChild(int sig)
-{
-    if (child_pid > 0)
-	kill(child_pid, SIGTERM);
-    _exit(0);
-}
-#endif
-
 /*ARGSUSED*/
 static void _X_NORETURN
 Quit(Widget widget, XEvent *event, String *params, Cardinal *num_params)
 {
-#ifdef USE_OSM
-    if (child_pid > 0)
-	kill(child_pid, SIGTERM);
-#endif
     exit (0);
 }
 
-#ifdef USE_OSM
-static int (*ioerror)(Display *);
-
-static int
-IOError(Display *dpy)
-{
-    if (child_pid > 0)
-	kill(child_pid, SIGTERM);
-    return (*ioerror)(dpy);
-}
-#endif
-
 static void
 Notify(void)
 {
@@ -609,6 +552,20 @@ InsertSelection(Widget w, XtPointer client_data, Atom *selection, Atom *type,
     OpenConsole ();
 }
 
+static void _X_NORETURN
+usage(int exitval)
+{
+    const char *usage_message =
+    "usage: xconsole [-toolkitoption  ...] [-file file-name] [-notify|-nonotify]\n"
+    "                [-stripNonprint] [-daemon] [-verbose] [-exitOnFail]\n"
+    "                [-saveLines count]\n"
+    "       xconsole -help\n"
+    "       xconsole -version\n";
+
+    fputs(usage_message, stderr);
+    exit(exitval);
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -616,8 +573,34 @@ main(int argc, char *argv[])
     Cardinal num_args;
 
     XtSetLanguageProc(NULL,NULL,NULL);
+
+    /* Handle args that don't require opening a display */
+    for (int n = 1; n < argc; n++) {
+	const char *argn = argv[n];
+	/* accept single or double dash for -help & -version */
+	if (argn[0] == '-' && argn[1] == '-') {
+	    argn++;
+	}
+	if (strcmp(argn, "-help") == 0) {
+	    usage(0);
+	}
+	if (strcmp(argn, "-version") == 0) {
+	    puts(PACKAGE_STRING);
+	    exit(0);
+	}
+    }
+
     top = XtInitialize ("xconsole", "XConsole", options, XtNumber (options),
 			&argc, argv);
+    if (argc != 1) {
+        fputs("Unknown argument(s):", stderr);
+        for (int n = 1; n < argc; n++) {
+            fprintf(stderr, " %s", argv[n]);
+        }
+        fputs("\n\n", stderr);
+        usage(1);
+    }
+
     XtGetApplicationResources (top, (XtPointer)&app_resources, resources,
 			       XtNumber (resources), NULL, 0);
 
@@ -656,9 +639,6 @@ main(int argc, char *argv[])
 		       ConvertSelection, LoseSelection, NULL);
 	OpenConsole ();
     }
-#ifdef USE_OSM
-    ioerror = XSetIOErrorHandler(IOError);
-#endif
     XtMainLoop ();
     return 0;
 }
@@ -789,19 +769,18 @@ ScrollLine(Widget w)
  */
 
 static int
-get_pty(int *pty, int *tty, char *ttydev, char *ptydev)
+get_pty(int *pty, int *tty)
 {
 #ifdef HAS_OPENPTY
 	if (openpty(pty, tty, NULL, NULL, NULL) == -1) {
 		return 1;
 	}
 	return 0;
-#elif defined (SVR4) || defined (USE_PTS)
-#if defined (_AIX)
-	if ((*pty = open ("/dev/ptc", O_RDWR)) < 0)
 #else
+	static char ttydev[64], ptydev[64];
+
+#if defined (SVR4) || defined (USE_PTS)
 	if ((*pty = open ("/dev/ptmx", O_RDWR)) < 0)
-#endif
 	    return 1;
 	grantpt(*pty);
 	unlockpt(*pty);
@@ -823,14 +802,6 @@ get_pty(int *pty, int *tty, char *ttydev, char *ptydev)
 #else
 	static int devindex, letter = 0;
 
-#ifdef sgi
-	{
-	    char *slave;
-	    slave = _getpty (pty, O_RDWR, 0622, 0);
-	    if ((*tty = open (slave, O_RDWR)) != -1)
-		return 0;
-	}
-#else
 	strcpy (ttydev, "/dev/ttyxx");
 	strcpy (ptydev, "/dev/ptyxx");
 	while (PTYCHAR1[letter]) {
@@ -857,7 +828,6 @@ get_pty(int *pty, int *tty, char *ttydev, char *ptydev)
 	    devindex = 0;
 	    (void) letter++;
 	}
-#endif /* sgi else not sgi */
 #endif /* USE_GET_PSEUDOTTY */
 #endif /* SVR4 */
 	/*
@@ -865,82 +835,6 @@ get_pty(int *pty, int *tty, char *ttydev, char *ptydev)
 	 * condition and let our caller terminate cleanly.
 	 */
 	return(1);
+#endif /* HAS_OPENPTY */
 }
 #endif
-
-#ifdef USE_OSM
-/*
- * On SYSV386 there is a special device, /dev/osm, where system messages
- * are sent.  Problem is that we can't perform a select(2) on this device.
- * So this routine creates a streams-pty where one end reads the device and
- * sends the output to xconsole.
- */
-
-#ifdef SCO325
-#define	OSM_DEVICE	"/dev/error"
-#else
-#ifdef __UNIXWARE__
-#define OSM_DEVICE	"/dev/osm2"
-#define NO_READAHEAD
-#else
-#define	OSM_DEVICE	"/dev/osm"
-#endif
-#endif
-
-static FILE *
-osm_pipe(void)
-{
-    int tty;
-    char ttydev[64];
-
-    if (access(OSM_DEVICE, R_OK) < 0)
-	return NULL;
-#if defined (_AIX)
-    if ((tty = open("/dev/ptc", O_RDWR)) < 0)
-#else
-    if ((tty = open("/dev/ptmx", O_RDWR)) < 0)
-#endif
-	return NULL;
-
-    grantpt(tty);
-    unlockpt(tty);
-    strcpy(ttydev, (char *)ptsname(tty));
-
-    if ((child_pid = fork()) == 0)
-    {
-	int pty, osm, nbytes, skip;
-	char cbuf[128];
-
-	skip = 0;
-#ifndef NO_READAHEAD
-	osm = open(OSM_DEVICE, O_RDONLY);
-	if (osm >= 0)
-	{
-	    while ((nbytes = read(osm, cbuf, sizeof(cbuf))) > 0)
-		skip += nbytes;
-	    close(osm);
-	}
-#endif
-	pty = open(ttydev, O_RDWR);
-	if (pty < 0)
-	    exit(1);
-	osm = open(OSM_DEVICE, O_RDONLY);
-	if (osm < 0)
-	    exit(1);
-	for (nbytes = 0; skip > 0 && nbytes >= 0; skip -= nbytes)
-	{
-	    nbytes = skip;
-	    if (nbytes > sizeof(cbuf))
-		nbytes = sizeof(cbuf);
-	    nbytes = read(osm, cbuf, nbytes);
-	}
-	while ((nbytes = read(osm, cbuf, sizeof(cbuf))) >= 0)
-	    write(pty, cbuf, nbytes);
-	exit(0);
-    }
-    signal(SIGHUP, KillChild);
-    signal(SIGINT, KillChild);
-    signal(SIGTERM, KillChild);
-    return fdopen(tty, "r");
-}
-#endif  /* USE_OSM */
